Exception: ConnectClient::Http::AsyncHttpError

Inherits:
StandardError
  • Object
show all
Defined in:
lib/connect_client/http/event_endpoint.rb

Instance Method Summary collapse

Instance Method Details

#messageObject



131
132
133
# File 'lib/connect_client/http/event_endpoint.rb', line 131

def message
  "You have tried to push events asynchronously without an event machine event loop running. The easiest way to do this is by passing a block to EM.run"
end